@@ -184,7 +184,7 @@ static PilRecInfo recipe_info = {NULL, NULL, NULL, 0, 0, NULL};
  * another dash which must be followed by a lower or upper case letter.
  */
 
-inline static int
+ static int
 is_option(const char *string)
 {
 
@@ -237,7 +237,7 @@ is_option(const char *string)
  * returns.
  */
 
-inline static int
+ static int
 copy(const char *srcpath, const char *dstpath)
 {
 
@@ -321,7 +321,7 @@ copy(const char *srcpath, const char *dstpath)
  * returns and the source file is left untouched.
  */
 
-inline static int
+ static int
 move(const char *srcpath, const char *dstpath)
 {
 
@@ -358,7 +358,7 @@ move(const char *srcpath, const char *dstpath)
  * and version string. It also assigns @c NULL to the pointers.
  */
 
-inline static void
+ static void
 deleteRecInfo(void)
 {
 
@@ -404,7 +404,7 @@ deleteRecInfo(void)
  * group name can be deallocated using @b pil_free().
  */
 
-inline static char *
+ static char *
 pilRecGetGroupName(const char *name) {
 
   char *group = NULL;
@@ -448,7 +448,7 @@ pilRecGetGroupName(const char *name) {
  * assuming that all recipe parameters have to be followed by an argument.
  */
 
-inline static struct option *
+ static struct option *
 pilRecMergeOptions(PilRecOption *ropt, PilRecParameter *rpar)
 {
 
@@ -522,7 +522,7 @@ pilRecMergeOptions(PilRecOption *ropt, PilRecParameter *rpar)
  * structure @em options and finally deallocates the structure itself.
  */
 
-inline static void
+ static void
 pilRecFreeMergedOptions(struct option *options)
 {
 
@@ -555,7 +555,7 @@ pilRecFreeMergedOptions(struct option *options)
  * parameter descriptions from the parameter objects comment field.
  */
 
-inline static void
+ static void
 pilRecUsage(PilRecParameter *parg)
 {
 
@@ -680,7 +680,7 @@ pilRecUsage(PilRecParameter *parg)
  * global recipe info structure @c recipe_info.
  */
 
-inline static void
+ static void
 pilRecVersion(void)
 {
 
@@ -736,7 +736,7 @@ pilRecVersion(void)
  * and starting time to the standard output.
  */
 
-inline static void
+ static void
 pilRecTimerStart()
 {
 
@@ -760,7 +760,7 @@ pilRecTimerStart()
  * elapsed since recipe start are written to the standard output.
  */
 
-inline static void
+ static void
 pilRecTimerStop(void)
 {
 
@@ -801,7 +801,7 @@ pilRecTimerStop(void)
  * @see pilMsgEnableLog()
  */
 
-inline static void
+ static void
 pilRecSetLogLevel(const char *log_level)
 {
 
@@ -840,7 +840,7 @@ pilRecSetLogLevel(const char *log_level)
  * @see pilMsgEnableTerminal()
  */
 
-inline static void
+ static void
 pilRecSetVerbosity(const char *verbosity)
 {
 
@@ -877,7 +877,7 @@ pilRecSetVerbosity(const char *verbosity)
  * configuration group does not exist it is created.
  */
 
-inline static int
+ static int
 pilRecParameterDefaults(PilRecParameter *rpar)
 {
 
@@ -976,7 +976,7 @@ pilRecParameterDefaults(PilRecParameter *rpar)
  *                      file running number in any case.
  */
 
-inline static char *
+ static char *
 pilRecBuildProductName(char *name, const char *path, const char *prefix,
                        int count, const PilFrame *frame)
 {
@@ -1141,7 +1141,7 @@ pilRecBuildProductName(char *name, const char *path, const char *prefix,
  * target directory. Otherwise the local products are moved.
  */
 
-inline static int
+ static int
 pilRecCopyProduct(PilFrame *frame, const char *path)
 {
 
@@ -1238,7 +1238,7 @@ pilRecCopyProduct(PilFrame *frame, const char *path)
  *   links cannot be used across file systems.
  */
 
-inline static int
+ static int
 pilRecExportProduct(const char *e_path, const char *p_path)
 {
 
@@ -1343,7 +1343,7 @@ pilRecExportProduct(const char *e_path, const char *p_path)
  * target directory. Otherwise the local logfile is moved to that directory.
  */
 
-inline static int
+ static int
 pilRecSaveLog(const char *filename, const char *path, const char *prefix)
 {
 
