@@ -532,6 +532,9 @@ static int vimos_calib(cpl_parameterlist *parlist, cpl_frameset *frameset)
     multiplex = mos_check_multiplex(maskslits);
 //    cpl_table_save(maskslits, NULL, NULL, "groups.fits", CPL_IO_DEFAULT);
 
+    if (cpl_error_get_code())
+        vimos_multi_exit("Error retrieving slit information from header");
+    
     if (multiplex == 1) {
 
         /*
