@@ -1158,6 +1158,7 @@ static int vimos_science(cpl_parameterlist *parlist, cpl_frameset *frameset,
         const char       *curv_coeff_tag       = "MOS_CURV_COEFF";
         const char       *slit_location_tag    = "MOS_SLIT_LOCATION";
         const char       *disp_coeff_tag       = "MOS_DISP_COEFF";
+        const char       *disp_coeff_sky_tag   = "MOS_SCI_DISP_COEFF_SKY";
         const char       *unmapped_science_tag = "MOS_UNMAPPED_SCIENCE";
         const char       *mapped_science_tag   = "MOS_SCIENCE_EXTRACTED";
         const char       *mapped_science_sky_tag = "MOS_SCIENCE_SKY_EXTRACTED";
@@ -1172,6 +1173,8 @@ static int vimos_science(cpl_parameterlist *parlist, cpl_frameset *frameset,
         const char     *reduced_flux_error_tag = "MOS_SCI_ERROR_FLUX_REDUCED";
         const char       *fringes_tag          = "MOS_SCI_FRINGES";
         const char       *specphot_tag         = "MOS_SPECPHOT_TABLE";
+        const char  *skylines_offsets_tag = "MOS_SCI_SKYLINES_OFFSETS_SLIT";
+        const char  *wavelength_map_sky_tag   = "MOS_SCI_WAVELENGTH_MAP_SKY";
 
         const char       *stack_method;
         const char       *alignment;
@@ -1517,16 +1520,16 @@ static int vimos_science(cpl_parameterlist *parlist, cpl_frameset *frameset,
              * (not really necessary, but clean)
              */
 
-            cpl_frameset_erase(work, "MOS_SKYLINES_OFFSETS_SLIT");
+            cpl_frameset_erase(work, skylines_offsets_tag);
             cpl_frameset_erase(work, unmapped_sky_tag);
             cpl_frameset_erase(work, unmapped_science_tag);
-            cpl_frameset_erase(work, "MOS_SCI_WAVELENGTH_MAP_SKY");
+            cpl_frameset_erase(work, wavelength_map_sky_tag);
             cpl_frameset_erase(work, mapped_sky_tag);
             cpl_frameset_erase(work, object_table_tag);
             cpl_frameset_erase(work, reduced_science_tag);
             cpl_frameset_erase(work, reduced_sky_tag);
             cpl_frameset_erase(work, reduced_error_tag);
-            cpl_frameset_erase(work, "MOS_SCI_DISP_COEFF_SKY");
+            cpl_frameset_erase(work, disp_coeff_sky_tag);
             cpl_frameset_erase(work, mapped_science_sky_tag);
             cpl_frameset_erase(work, mapped_science_tag);
 
@@ -2226,7 +2229,9 @@ static int vimos_science(cpl_parameterlist *parlist, cpl_frameset *frameset,
         cpl_propertylist_delete(header);
 
         system("rm object_table_*.fits "
-               "mos_unmapped_science_*.fits mos_unmapped_sky_*.fits");
+               "mos_unmapped_science_*.fits mos_unmapped_sky_*.fits "
+               "mos_sci_skylines_offsets_slit.fits "
+               "mos_sci_wavelength_map_sky.fits mos_sci_disp_coeff_sky.fits");
 
         return 0;
     }
