@@ -358,7 +358,7 @@ vmCplFramesetImport(cpl_frameset *set, const PilSetOfFrames *sof)
             }
 
             for (i = 0; i < nframes; i++) {
-                _frame = cpl_frameset_get_frame(set, i);
+                _frame = cpl_frameset_get_position(set, i);
                 _name = cpl_frame_get_filename(_frame);
                 if (strcmp(name, _name) == 0) {
                     cpl_frame_set_group(_frame, _group);
